/* emacs buffer mode hint -*- objc -*- */

#define FIRST_HOUR @"firstHour"
#define LAST_HOUR @"lastHour"
#define MIN_STEP @"minimumStep"

#define STORE_CLASSES @"storeClasses"

#define STORES @"stores"
#define ST_DEFAULT @"defaultStore"
#define ST_CLASS @"storeClass"
#define ST_FILE @"storeFilename"
#define ST_COLOR @"storeColor"
#define ST_TEXT_COLOR @"storeTextColor"
#define ST_URL @"storeURL"
#define ST_CALENDAR_URL @"storeCalendarURL"
#define ST_TASK_URL @"storeTaskURL"
#define ST_RW @"storeWritable"
#define ST_REFRESH @"storeRefresh"
#define ST_DISPLAY @"storeDisplay"
#define ST_VERSION @"storeVersion"
